<?php
/**
 * This file implements the AKVS OnlineDemo plugin for {@link http://b2evolution.net/}.
 *
 * @copyright (c) 2008 by Tilman Blumenbach - {@link http://www.ax86.net}.
 *
 * @license GNU General Public License 2 (GPL) - http://www.opensource.org/licenses/gpl-2.0.php
 *
 * @package plugins
 *
 * @author Tilman Blumenbach <tilman [AT] ax86 [DOT] net>
 */
if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );


/**
 * AKVS OnlineDemo Plugin
 *
 * Displays the AKVS pagepeel {@link http://wiki.vorratsdatenspeicherung.de/Online-Demo} on one or more blogs, configurable.
 *
 * @package plugins
 */
class akvs_onlinedemo_plugin extends Plugin
{
    var $name = 'AKVS OnlineDemo';
    var $code = '';
    var $priority = 50;
    var $version = '1.0.2';
    var $author = 'Tilman Blumenbach';
    var $help_url = 'http://www.ax86.net/2008/06/03/vorratsdatenspeicherung-pagepeel-plugin';
    var $group = 'advertisement';
    var $apply_rendering = 'never';
    /**
     * There can be only one install of this plugin, otherwise the HTML code would be messed up.
     */
    var $number_of_installs = 1;

    /**
     * Set by the SkinBeginHtmlHead() hook if the pagepeel <body> HTML code should be displayed by the SkinEndHtmlBody() hook.
     */
    var $_display = false;
    /**
     * The used version of the AKVS pagepeel.
     */
    var $_akvs_ver = '1.6';
    /**
     * The URL to the source/wiki page of the pagepeel.
     */
    var $_akvs_url = 'http://wiki.vorratsdatenspeicherung.de/Online-Demo';


    function PluginInit( & $params )
    {
        $this->short_desc = sprintf($this->T_('Displays the AKVS OnlineDemo pagepeel v%s. Configurable through its settings menu.'), $this->_akvs_ver);
        $this->long_desc = sprintf($this->T_('The pagepeel code can be found <a href="%s">here</a>.'), $this->_akvs_url);
    }

    function GetDefaultSettings(& $params)
    {
        return array(
            'blogs' => array(
                'label' => $this->T_('Display on the following blogs'),
                'note' => $this->T_('Enter the blog IDs, separated by a space.'),
                'type'  => 'text',
                'valid_pattern' => array(
                    'pattern' => '/^(\d ?)+$/',
                    'error' => sprintf($this->T_('The value is invalid. It must be in the format: %s'), '<code>&lt;ID&gt;[ &lt;ID&gt;]...</code>'),
                    ),
                ),
            'admin_hide' => array(
                'label' => $this->T_('Hide pagepeel when user is logged in as an admin'),
                'type' => 'checkbox',
                'defaultvalue' => 1,
                ),
            'loggedin_hide' => array(
                'label' => $this->T_('Hide pagepeel when user is logged in (but not admin)'),
                'type' => 'checkbox',
                'defaultvalue' => 1,
                ),
            );
    }

    function SkinBeginHtmlHead(& $params)
    {
        global $Blog, $current_User;

        if (is_logged_in())
        {
            $gid = $current_User->group_ID;
            if ($gid == 1 && $this->Settings->get('admin_hide')) // GID 1 is the admin group
            {   
                $this->debug_log('\'admin_hide\' active, user is logged in as an admin: not displaying pagepeel.');
                return false;
            }
            // if we don't check if the GID isn't 1, the admin won't see the pagepeel
            // if admin_hide is set to 0 and loggedin_hide to 1, so we better check here.
            else if ($gid != 1 && $this->Settings->get('loggedin_hide'))
            {
                $this->debug_log('\'loggedin_hide\' active, user is logged in and not admin: not displaying pagepeel.');
                return false;
            }
        }
        
        $blogs = $this->Settings->get('blogs');
        $this->debug_log('Value of \'blogs\' setting: '.var_export($blogs, true));

        $blogs = explode(' ', $blogs);
        $this->debug_log('$blogs after explode(): '.var_export($blogs, true));
        if (in_array($Blog->ID, $blogs))
        {
            $this->_display = true;
            $this->debug_log('Blog '.$Blog->ID.' found in $blogs array, displaying &lt;head&gt; HTML code.');
            echo <<<EOT
<!-- AKVS head start v1.6 -->
<style type="text/css">
<!--
div#akct {
	position: absolute; top:0px; right: 0px; z-index: 2342; width:113px; height:88px;
	background-image: url(http://wiki.vorratsdatenspeicherung.de/images/Akvse.gif);
	background-repeat: no-repeat;
	background-position: right top;
	border:none;
	padding:0;
	margin:0;
	text-align: right;
}

div#akct img {
	border:none;
	padding:0;
	margin:0;
	background: none;
}

div#akct a#akpeel img {
        width: 113px;
        height: 88px;
}

div#akct a, div#akct a:hover {
	text-decoration: none;
	border:none;
	padding:0;
	margin:0;
	display: block;
	background: none;
}

div#akct a#akpeel:hover {
	position: absolute; top:0px; right: 0px; z-index: 4223; width:500px; height:500px;
	display: block;
	background-image: url(http://wiki.vorratsdatenspeicherung.de/images/Akvsb.gif);
	background-repeat: no-repeat;
	background-position: right top;
}

div#akct a#akpreload {
	background-image: url(http://wiki.vorratsdatenspeicherung.de/images/Akvsb.gif);
	background-repeat: no-repeat;
	background-position: 234px 0px;
}
-->
</style>
<!--[if gte IE 5.5]>
<![if lt IE 7]>
<style type="text/css">
div#akct a#akpeel:hover {
		right: -1px;
}
</style>
<![endif]>
<![endif]-->
<!-- AKVS head end -->
EOT;
        }
        else
        {
            $this->debug_log('Blog '.$Blog->ID.' NOT FOUND in $blogs array, not displaying &lt;head&gt; HTML code.');
            return false;
        }
        return true;
    }

    function SkinEndHtmlBody(&$params)
    {
        if (!$this->_display)
        {
            $this->debug_log('Not displaying &lt;body&gt; HTML code.');
            return false;
        }
        $this->debug_log('Displaying &lt;body&gt; HTML code.');
        
        echo <<<EOT
<!-- AKVS body start v1.6 -->
<div id="akct"><a id="akpeel" href="http://www.vorratsdatenspeicherung.de/aktuell" 
target="_blank" title="Stoppt die Vorratsdatenspeicherung! Jetzt klicken &amp; handeln!"><img
src="http://wiki.vorratsdatenspeicherung.de/images/Akvst.gif"
alt="Stoppt die Vorratsdatenspeicherung! Jetzt klicken &amp;handeln!" /></a>
<a id="akpreload" href="http://wiki.vorratsdatenspeicherung.de/?title=Online-Demo" target="_blank" 
title="Willst du auch an der Aktion teilnehmen? Hier findest du alle relevanten Infos und
Materialien:"><img src="http://wiki.vorratsdatenspeicherung.de/images/Akvsi.gif"
alt="Willst du auch an der Aktion teilnehmen? Hier findest du alle relevanten Infos
und Materialien:" /></a></div>
<!-- AKVS body end -->
EOT;
        return true;
    }
}
?>
